### Contexto
(*las líneas entre paréntesis son informativas y deberán borrarse al crear el ticket)

(*describir muy brevemente el contexto de partida de la tarea*)
(*con la óptica de una persona que acaba de empezar a trabajar en el proyecto*)

- subtarea de `nanocore`, ticket #1  (*poner el número del ticket padre*)
- dato de contexto 2 (*si procede*)
- dato de contexto 3 (*si procede*)

### Tareas

(*aunque el interfaz web aparezca más resumido, internamente no hay ninguna diferencia con un ticket normal, así que procedemos igual que la tarea padre, pero describiendo las actividades en este nivel más bajo*)

(*describir brevemente cada una de las microtareas en las que la persona que ha descrito el ticket le gustaría ver como avanza el ticket*)

(*es posible ir marcando desde la web cuando cada una de estas microtareas se ha hecho, notificando a los interesados, y alimentando el histórico del ticket*)

- [ ] hacer xxx
- [ ] hacer yyy

### Resultados
(*describir como el creador del ticket piensa que deberá reflejarse el resultado final*)
(*deberá ser suficiente como para que un tercero pueda verificar que está correctamente realizada*)

- [ ] commit xxx
- [ ] wiki yyy

